@@ -177,11 +177,35 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         QString toolTipString = i18n("<p><b>Priority %1:</b>%2</p>", SKGServices::intToString(ad.getPriority()), ad.getLongMessage());
 
         // Add ignored action
-        QStringList autoCorrections = ad.getAutoCorrections();
-        autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss"));
-        autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss during current month"));
-        autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss this kind"));
-        autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss this kind during current month"));
+        QList<SKGAdvice::SKGAdviceAction> autoCorrections = ad.getAutoCorrections();
+	{
+	  SKGAdvice::SKGAdviceAction dismiss;
+	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss");
+	  dismiss.IconName="edit-delete";
+	  dismiss.IsRecommended=false;
+	  autoCorrections.push_back(dismiss);
+	}
+	{
+	  SKGAdvice::SKGAdviceAction dismiss;
+	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss during current month");
+	  dismiss.IconName="edit-delete";
+	  dismiss.IsRecommended=false;
+	  autoCorrections.push_back(dismiss);
+	}
+	{
+	  SKGAdvice::SKGAdviceAction dismiss;
+	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss this kind");
+	  dismiss.IconName="edit-delete";
+	  dismiss.IsRecommended=false;
+	  autoCorrections.push_back(dismiss);
+	}
+	{
+	  SKGAdvice::SKGAdviceAction dismiss;
+	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss this kind during current month");
+	  dismiss.IconName="edit-delete";
+	  dismiss.IsRecommended=false;
+	  autoCorrections.push_back(dismiss);
+	}	
 
         int nbSolution = autoCorrections.count();
 
@@ -199,20 +223,26 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         KMenu* menu = new KMenu(this);
         menu->setIcon(icon->icon());
         for (int k = 0; k < nbSolution; ++k) {
-            QString actionText = autoCorrections.at(k);
+	    SKGAdvice::SKGAdviceAction adviceAction=autoCorrections.at(k);
+            QString actionText = adviceAction.Title;
             QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove("skg://"), false);
+	    QAction* act;
             if (action) {
                 // This is an action
-                QAction* act = menu->addAction(action->icon(), action->text(), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+                act = menu->addAction(action->icon(), action->text(), SKGMainPanel::getMainPanel(), SLOT(openPage()));
                 act->setData(actionText);
             } else {
                 // This is a text
-                QAction* act = menu->addAction(KIcon(k < nbSolution - 4 ?  "system-run" : "edit-delete"), autoCorrections.at(k), this, SLOT(adviceClicked()));
+                act = menu->addAction(KIcon(adviceAction.IconName.isEmpty() ?  "system-run" : adviceAction.IconName), actionText, this, SLOT(adviceClicked()));
                 if (act) {
                     act->setProperty("id", ad.getUUID());
                     act->setProperty("solution", k < nbSolution - 4 ? k : k - nbSolution);
                 }
             }
+            
+            if(act && adviceAction.IsRecommended) {
+	      act->setText(act->text() % i18nc("To recommend this action", " (recommended)"));
+	    }
         }
 
         icon->setMenu(menu);
