@@ -43,18 +43,18 @@ SKGDashboardPlugin::SKGDashboardPlugin(QWidget* iWidget, QObject* iParent, const
 {
     Q_UNUSED(iArg);
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGDashboardPlugin::SKGDashboardPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGDashboardPlugin::~SKGDashboardPlugin()
 {
-    SKGTRACEIN(10, "SKGDashboardPlugin::~SKGDashboardPlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
 }
 
 bool SKGDashboardPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGDashboardPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -68,7 +68,7 @@ bool SKGDashboardPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 SKGTabPage* SKGDashboardPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGDashboardPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGDashboardPluginWidget(m_currentDocument);
 }
 
