@@ -56,6 +56,7 @@ SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, con
     m_billsProcess.start("boobill bills  -q -f csv -v");
 
     connect(&m_billsProcess, SIGNAL(finished(int)), this, SLOT(onBillsRetreived()));
+    connect(&m_billsProcess, SIGNAL(error(QProcess::ProcessError)), this, SLOT(onBillsRetreived()));    
 }
 
 SKGPropertiesPlugin::~SKGPropertiesPlugin()
@@ -86,9 +87,9 @@ void SKGPropertiesPlugin::onBillsRetreived()
         }
 
         // close file
-        file.close();
-        file.remove();
+        file.close(); 
     }
+    file.remove();
 }
 
 bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -226,7 +227,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
             // Get list of more used properties for this table
             SKGStringListList listTmp;
             m_currentDocument->executeSelectSqliteOrder(
-                "SELECT t_name, t_value FROM (SELECT t_name, t_value, COUNT(1) AS nb FROM parameters WHERE t_uuid_parent like '%-" % table % "' AND t_name NOT LIKE 'SKG_%' AND b_blob IS NULL GROUP BY t_name, t_value) ORDER BY nb DESC LIMIT 7",
+                "SELECT t_name, t_value FROM (SELECT t_name, t_value, COUNT(1) AS nb FROM parameters WHERE (t_uuid_parent like '%-" % table % "' OR t_uuid_parent like '%-sub" % table % "') AND t_name NOT LIKE 'SKG_%' AND b_blob IS NULL GROUP BY t_name, t_value) ORDER BY nb DESC LIMIT 7",
                 listTmp);
 
             // Create actions
