@@ -127,8 +127,12 @@ void SKGPropertiesPluginDockWidget::refresh()
                 }
 
                 // Fill combo box
-                SKGMainPanel::fillWithDistinctValue(ui.kAttribute, getDocument(), "parameters", "t_name", "t_uuid_parent like '%-" % tableName % "' AND t_name NOT LIKE 'SKG_%'");
-                SKGMainPanel::fillWithDistinctValue(ui.kValue, getDocument(), "parameters", "t_value", "t_uuid_parent like '%-" % tableName % "' AND t_name NOT LIKE 'SKG_%'");
+                QString t=tableName;
+		if(t.startsWith(QLatin1String("sub"))) {
+		  t=t.right(t.length()-3);
+		}
+                SKGMainPanel::fillWithDistinctValue(ui.kAttribute, getDocument(), "parameters", "t_name", "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
+                SKGMainPanel::fillWithDistinctValue(ui.kValue, getDocument(), "parameters", "t_value", "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
             } else {
                 filter += "'XXX'";  // Always false
                 ui.kAdd->setEnabled(false);
