@@ -22,6 +22,7 @@
 #include "skgimportpluginofx.h"
 
 #include <QFileInfo>
+#include <qcryptographichash.h>
 
 #include <KLocale>
 #include <KGenericFactory>
@@ -211,111 +212,112 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     }
 
     SKGObjectBase tmp;
-    if (data.account_id_valid == true) {
-        QString agencyNumber = QString::fromUtf8(data.branch_id);
-        QString accountNumber = QString::fromUtf8(data.account_id);
-        QString bankNumber = QString::fromUtf8(data.bank_id);
-        // Correction BUG 234771 vvvvv
-        accountNumber = accountNumber.trimmed();
-        bankNumber = bankNumber.trimmed();
-        // Correction BUG 234771 ^^^^^
-        if (accountNumber.startsWith(bankNumber % ' ')) {
-            accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-            QStringList splitNumbers = accountNumber.split(' ');
-            if (splitNumbers.count() == 2) {
-                agencyNumber = splitNumbers.at(0);
-                accountNumber = splitNumbers.at(1);
-            }
-        }
-
-        // Check if account is already existing
-        SKGAccountObject account;
-        SKGImportPluginOfx::m_ofxError = getAccount(&data, doc, account);
-        if (!SKGImportPluginOfx::m_ofxError) {
-            // Already existing
-            account = tmp;
-            SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
-        } else {
-            // Not existing
-            QString bankId = (data.bank_id_valid == true ? QString::fromUtf8(data.bank_id) : (data.broker_id_valid == true ? QString::fromUtf8(data.broker_id) : i18nc("Adjective, an unknown item", "Unknown")));
-            if (!bankId.isEmpty()) {
-                // Check if bank is already existing
-                SKGBankObject bank;
-                SKGImportPluginOfx::m_ofxError = doc->getObject("v_bank", "t_bank_number='" % bankId % '\'', tmp);
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    // Already existing
-                    bank = tmp;
-                } else {
-                    // Create new bank
-                    bank = SKGBankObject(doc);
-                    SKGImportPluginOfx::m_ofxError = bank.setName(bankId);
-                    if (!SKGImportPluginOfx::m_ofxError) {
-                        SKGImportPluginOfx::m_ofxError = bank.setNumber(QString::fromUtf8(data.bank_id));
-                    }
-                    if (!SKGImportPluginOfx::m_ofxError) {
-                        SKGImportPluginOfx::m_ofxError = bank.save();
-                    }
-                }
-
-                // Create new account
-                QString name = QString::fromUtf8(data.account_name);
-                if (name.isEmpty()) {
-                    name = QString::fromUtf8(data.account_id);
-                } else {
-                    name = name.remove("Bank account ");
-                }
-
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = bank.addAccount(account);
-                }
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.setName(name);
-                }
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.setNumber(accountNumber);
-                }
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.setAgencyNumber(agencyNumber);
-                }
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.setComment(QString::fromUtf8(data.account_name));
-                }
-                SKGAccountObject::AccountType type = SKGAccountObject::CURRENT;
-                if (data.account_type_valid == true) {
-                    switch (data.account_type) {
-                    case OfxAccountData::OFX_CHECKING:
-                    case OfxAccountData::OFX_SAVINGS:
-                    case OfxAccountData::OFX_CREDITLINE:
-                    case OfxAccountData::OFX_CMA:
-                        type = SKGAccountObject::CURRENT;
-                        break;
-                    case OfxAccountData::OFX_MONEYMRKT:
-                    case OfxAccountData::OFX_INVESTMENT:
-                        type = SKGAccountObject::INVESTMENT;
-                        break;
-                    case OfxAccountData::OFX_CREDITCARD:
-                        type = SKGAccountObject::CREDITCARD;
-                        break;
-                    default:
-                        break;
-                    }
-                }
-
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.setType(type);
-                }
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = account.save();
-                }
-
-                if (!SKGImportPluginOfx::m_ofxError) {
-                    SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
-                }
-
-                SKGTRACEL(10) << "Account [" << name << "] created" << endl;
-            }
-        }
+    QString agencyNumber = QString::fromUtf8(data.branch_id);
+    QString accountNumber = QString::fromUtf8(data.account_id);
+    QString bankNumber = QString::fromUtf8(data.bank_id);
+    // Correction BUG 234771 vvvvv
+    accountNumber = accountNumber.trimmed();
+    bankNumber = bankNumber.trimmed();
+    // Correction BUG 234771 ^^^^^
+    if (accountNumber.startsWith(bankNumber % ' ')) {
+	accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
+	QStringList splitNumbers = accountNumber.split(' ');
+	if (splitNumbers.count() == 2) {
+	    agencyNumber = splitNumbers.at(0);
+	    accountNumber = splitNumbers.at(1);
+	}
     }
+
+    // Check if account is already existing
+    SKGAccountObject account;
+    SKGImportPluginOfx::m_ofxError = getAccount(&data, doc, account);
+    if (!SKGImportPluginOfx::m_ofxError) {
+	// Already existing
+	account = tmp;
+	SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
+    } else {
+	// Not existing
+	QString bankId = (data.bank_id_valid == true ? QString::fromUtf8(data.bank_id) : QString::fromUtf8(data.broker_id));
+	if (!bankId.isEmpty()) {
+	  bankId = i18nc("Adjective, an unknown item", "Unknown");
+	}
+	
+	// Check if bank is already existing
+	SKGBankObject bank;
+	SKGImportPluginOfx::m_ofxError = doc->getObject("v_bank", "t_bank_number='" % bankId % '\'', tmp);
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    // Already existing
+	    bank = tmp;
+	} else {
+	    // Create new bank
+	    bank = SKGBankObject(doc);
+	    SKGImportPluginOfx::m_ofxError = bank.setName(bankId);
+	    if (!SKGImportPluginOfx::m_ofxError) {
+		SKGImportPluginOfx::m_ofxError = bank.setNumber(QString::fromUtf8(data.bank_id));
+	    }
+	    if (!SKGImportPluginOfx::m_ofxError) {
+		SKGImportPluginOfx::m_ofxError = bank.save();
+	    }
+	}
+
+	// Create new account
+	QString name = QString::fromUtf8(data.account_name);
+	if (name.isEmpty()) {
+	    name = QString::fromUtf8(data.account_id);
+	} else {
+	    name = name.remove("Bank account ");
+	}
+
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = bank.addAccount(account);
+	}
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.setName(name);
+	}
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.setNumber(accountNumber);
+	}
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.setAgencyNumber(agencyNumber);
+	}
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.setComment(QString::fromUtf8(data.account_name));
+	}
+	SKGAccountObject::AccountType type = SKGAccountObject::CURRENT;
+	if (data.account_type_valid == true) {
+	    switch (data.account_type) {
+	    case OfxAccountData::OFX_CHECKING:
+	    case OfxAccountData::OFX_SAVINGS:
+	    case OfxAccountData::OFX_CREDITLINE:
+	    case OfxAccountData::OFX_CMA:
+		type = SKGAccountObject::CURRENT;
+		break;
+	    case OfxAccountData::OFX_MONEYMRKT:
+	    case OfxAccountData::OFX_INVESTMENT:
+		type = SKGAccountObject::INVESTMENT;
+		break;
+	    case OfxAccountData::OFX_CREDITCARD:
+		type = SKGAccountObject::CREDITCARD;
+		break;
+	    default:
+		break;
+	    }
+	}
+
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.setType(type);
+	}
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = account.save();
+	}
+
+	if (!SKGImportPluginOfx::m_ofxError) {
+	    SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
+	}
+
+	SKGTRACEL(10) << "Account [" << name << "] created" << endl;
+    }
+        
     if (data.currency_valid == true) {
         // Check if unit is already existing
         SKGUnitObject unit(doc);
@@ -380,6 +382,11 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
                 ID = QString("REF-") % data.reference_number;
             }
         }
+        
+        if(ID.isEmpty()){
+	    QByteArray hash = QCryptographicHash::hash(QString(SKGServices::dateToSqlString(date) % SKGServices::doubleToString(data.amount)).toUtf8(), QCryptographicHash::Md5);
+	    ID = QString("ID-") % hash.toHex();
+	}
 
         // Create operation
         SKGOperationObject ope;
@@ -470,7 +477,10 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop);
         }
         if (!SKGImportPluginOfx::m_ofxError && data.amount_valid == true) {
-            SKGImportPluginOfx::m_ofxError = subop.setQuantity(data.amount + (data.commission_valid == true ? data.commission : 0));
+            bool mustFlipSign = data.transactiontype == OFX_DEBIT && data.amount > 0; // OFX spec version 2.1.1, section 3.2.9.2
+            double sign = mustFlipSign == true ? -1.0 : 1.0;
+            double commission = data.commission_valid == true ? data.commission : 0;
+            SKGImportPluginOfx::m_ofxError = subop.setQuantity(sign * (data.amount + commission));
         }
         if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) {
             SKGImportPluginOfx::m_ofxError = subop.setComment(QString::fromUtf8(data.memo));
