@@ -111,6 +111,7 @@ private Q_SLOTS:
     void onAddAccountClicked();
     void onModifyAccountClicked();
     void onSelectionChanged();
+    void onRefreshGraphDelayed();
     void onRefreshGraph();
     void onComputeRIB();
     void cleanEditor();
@@ -124,6 +125,7 @@ private:
     QTimer m_timer;
     QTimer m_timer2;
     SKGBoardWidget* m_graph;
+    QString m_graphState;
 };
 
 #endif  // SKGDEBUGPLUGIN_H
