@@ -140,8 +140,14 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(3);
             ad.setShortMessage(i18nc("User did not define an interest rate on an investment account", "No interest rate defined for account '%1'", account.getName()));
             ad.setLongMessage(i18nc("User did not define an interest rate on an investment account", "Your investment account '%1' doesn't have interest rate defined", account.getName()));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page"));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page");
+	      a.IconName="skg_open";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }	    
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
