@@ -366,8 +366,8 @@ void SKGImportExportPlugin::refresh()
                         // The automatic import is not done if at least one manual import has not been done
                         QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
                         if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgimportexport_settings::download_frequency() == 0) ||
-                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgimportexport_settings::download_frequency() == 1) ||
-                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgimportexport_settings::download_frequency() == 2))
+                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgimportexport_settings::download_frequency() == 1) ||
+                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgimportexport_settings::download_frequency() == 2))
 
                         {
                             // Import
@@ -884,9 +884,19 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations imported and not yet validated"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed."));
-            QStringList autoCorrections;
-            autoCorrections.push_back("skg://view_open_not_validated");
-            autoCorrections.push_back("skg://process_validate");
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title="skg://view_open_not_validated";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title="skg://process_validate";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }	    
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -914,11 +924,21 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
                 ad.setPriority(8);
                 ad.setShortMessage(i18nc("Advice on making the best (short)", "Krunner's operation ongoing [%1 %2 %3]", date, amount, payee));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "Operations created through krunner have to be fully created in skrooge."));
-                QStringList autoCorrections;
+		QList<SKGAdvice::SKGAdviceAction> autoCorrections;
                 for (int j = 0; j < nbAccounts; ++j) {
-                    autoCorrections.push_back(i18nc("Advice on making the best (action)", "Import operation in %1", listAccounts.at(j)));
+		    SKGAdvice::SKGAdviceAction a;
+		    a.Title=i18nc("Advice on making the best (action)", "Import operation in %1", listAccounts.at(j));
+		    a.IconName=icon();
+		    a.IsRecommended=false;
+		    autoCorrections.push_back(a);		  
                 }
-                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Remove operation"));
+		{
+		  SKGAdvice::SKGAdviceAction a;
+		  a.Title=i18nc("Advice on making the best (action)", "Remove operation");
+		  a.IconName="edit-delete";
+		  a.IsRecommended=false;
+		  autoCorrections.push_back(a);
+		}                
                 ad.setAutoCorrections(autoCorrections);
                 output.push_back(ad);
 
