@@ -133,7 +133,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     // Adding properties
     QStringList properties;
-    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
+    iDocument->getDistinctValues("parameters", "t_name", "(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation')  AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
     for (int i = 0; i < nb; ++i) {
         m_attsForLines.push_back("p_" % properties.at(i));
@@ -464,8 +464,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
             att = "";
         }
         if (att.startsWith(QLatin1String("p_"))) {
-            QString propertyName = att.right(att.length() - 2);
-            att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+            att = getWhereClauseForProperty(att);
         }
         if (att.isEmpty()) {
             att = '\'' % i18nc("Noun", "All") % '\'';
@@ -504,8 +503,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         att = "";
     }
     if (att.startsWith(QLatin1String("p_"))) {
-        QString propertyName = att.right(att.length() - 2);
-        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+        att = getWhereClauseForProperty(att);
     }
     if (!att.isEmpty()) {
         if (column != 0 && column < nbCol) {
@@ -904,8 +902,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     attCol = "";
                 }
                 if (attCol.startsWith(QLatin1String("p_"))) {
-                    QString propertyName = attCol.right(attCol.length() - 2);
-                    attCol = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+		    attCol = getWhereClauseForProperty(attCol);
                 }
 
                 QStringList listAtt = m_attsForLinesAdded;
@@ -920,8 +917,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         att = "";
                     }
                     if (att.startsWith(QLatin1String("p_"))) {
-                        QString propertyName = att.right(att.length() - 2);
-                        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+                        att = getWhereClauseForProperty(att);
                     }
                     if (att.isEmpty()) {
                         att = '\'' % i18nc("Noun", "All") % '\'';
@@ -1270,4 +1266,10 @@ void SKGReportPluginWidget::setSettings()
     ui.kTableWithGraph->redrawGraphDelayed();
 }
 
+QString SKGReportPluginWidget::getWhereClauseForProperty(const QString& iProperty) const
+{
+    QString propertyName = iProperty.right(iProperty.length() - 2);
+    return "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-suboperation' AND t_name='" % propertyName % "'), IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.i_OPID||'-operation' AND t_name='" % propertyName % "'), '#NULL#'))";    
+}
+
 #include "skgreportpluginwidget.moc"
