@@ -397,8 +397,14 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
                     ad.setPriority(percent >= 90 ? 9 : 6);
                     ad.setShortMessage(alarm.Message);
                     ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, m_currentBankDocument->formatMoney(alarm.Amount, primary), m_currentBankDocument->formatMoney(alarm.Limit, primary)));
-                    QStringList autoCorrections;
-                    autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
+		    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+		    {
+		      SKGAdvice::SKGAdviceAction a;
+		      a.Title=i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm");
+		      a.IconName="skg_open";
+		      a.IsRecommended=false;
+		      autoCorrections.push_back(a);
+		    }
                     ad.setAutoCorrections(autoCorrections);
                     output.push_back(ad);
                 }
