@@ -158,8 +158,8 @@ void SKGUnitPlugin::refresh()
                         }
                         QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
                         if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
-                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
-                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
+                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
+                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
 
                         {
                             // Download all units
@@ -298,9 +298,21 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(8);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a primary currency"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit);
+	      a.IconName=icon();
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
 
@@ -319,9 +331,21 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(2);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a secondary currency"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit);
+	      a.IconName=icon();
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }	    
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -342,10 +366,20 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
             if (!internet_code.isEmpty()) {
-                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Download '%1'", unit);
+	      a.IconName="download";
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);	      
             }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
@@ -383,9 +417,15 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The amount of the unit '%1' is not defined", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' has an amount defined at 1. Most of the time this is not normal and causes wrong computation. Check if this is normal.", unit));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
-            ad.setAutoCorrections(autoCorrections);
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
+	    ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
@@ -404,9 +444,15 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The definition of the unit '%1' is too complex", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' is defined relatively to another unit defined relatively to a third one. This is too complex and not supported by Skrooge.", unit));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
-            ad.setAutoCorrections(autoCorrections);
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
+	    ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
@@ -425,9 +471,15 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal.", unit));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
-            ad.setAutoCorrections(autoCorrections);
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Edit units");
+	      a.IconName=icon();
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
+	    ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
@@ -439,8 +491,14 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         ad.setPriority(9);
         ad.setShortMessage(i18nc("Advice on making the best (short)", "No decimal symbol defined"));
         ad.setLongMessage(i18nc("Advice on making the best (long)", "In KDE localization settings, there is no decimal symbol defined for currencies. This could be confusing."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit KDE settings"));
+	QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	{
+	  SKGAdvice::SKGAdviceAction a;
+	  a.Title=i18nc("Advice on making the best (action)", "Edit KDE settings");
+	  a.IconName="configure";
+	  a.IsRecommended=false;
+	  autoCorrections.push_back(a);
+	}
         ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
@@ -524,13 +582,10 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         }
 
         return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|"))) {
-        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
-        return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex"))) {
-        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
-        return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|"))) {
+    } else if (m_currentBankDocument && (iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|")) ||
+      iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex")) ||
+      iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|")))
+    ) {
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
