@@ -296,6 +296,8 @@ void SKGQueryCreator::onCloseEditor()
     if (!lineEmpty) {
         addNewLine();
     }
+
+    resizeColumns();
 }
 
 void SKGQueryCreator::onAddColumn()
@@ -326,6 +328,8 @@ void SKGQueryCreator::addColumnFromAttribut(const QListWidgetItem* listItem)
             ui.kList->setItem(i, nb, new QTableWidgetItem());
         }
         ui.kList->blockSignals(previous);
+
+        resizeColumns();
     }
 }
 
@@ -350,7 +354,7 @@ void SKGQueryCreator::addNewLine()
         }
         ui.kList->blockSignals(previous);
 
-        ui.kList->resizeColumnsToContents();
+        resizeColumns();
     }
 }
 
@@ -380,5 +384,12 @@ void SKGQueryCreator::removeLine(int iRow)
     onCloseEditor();
 }
 
+void SKGQueryCreator::resizeColumns()
+{
+    ui.kList->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+    qApp->processEvents(QEventLoop::AllEvents, 300);
+    ui.kList->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+}
+
 #include "skgquerycreator.moc"
 
