@@ -286,7 +286,7 @@ SKGError SKGImportExportManager::finalizeImportation()
         int nbOperations;
         err = m_document->getNbObjects("v_operation", wc, nbOperations);
         if (!err && nbOperations) {
-            err = m_document->sendMessage(i18np("One operation not imported because it already exists", "%1 operations not imported because they already exists", nbOperations), SKGDocument::Warning);
+            err = m_document->sendMessage(i18np("One operation not imported because it already exists", "%1 operations not imported because they already exist", nbOperations), SKGDocument::Warning);
 
             // Remove operations imported for nothing
             IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')'))
@@ -683,6 +683,11 @@ SKGError SKGImportExportManager::anonymize()
             }
 
             IFOKDO(err, m_document->removeAllTransactions())
+            QString newName = m_document->getCurrentFileName().replace(".skg", "-anonymized.skg");
+            if (newName == m_document->getCurrentFileName()) {
+                newName = m_document->getCurrentFileName() % "-anonymized.skg";
+            }
+            IFOKDO(err, m_document->saveAs(newName, true))
         }
     }
     return err;
