@@ -284,7 +284,7 @@ SKGError SKGOperationObject::getGroupedOperations(SKGListSKGObjectBase& oGrouped
 {
     SKGError err;
     QString gpId1 = getAttribute("i_group_id");
-    if (gpId1 == "0") {
+    if (gpId1 == "0" || gpId1.isEmpty()) {
         oGroupedOperations.clear();
     } else {
         err = getDocument()->getObjects("v_operation", "i_group_id=" % gpId1, oGroupedOperations);
@@ -484,7 +484,7 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
     return err;
 }
 
-SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne, SKGOperationObject::AmountAlignmentMode iMode)
+SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne, SKGOperationObject::AmountAlignmentMode iMode, bool iSendMessage)
 {
     // Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
@@ -542,7 +542,9 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
             }
         }
         IFOKDO(err, load())
-        IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
+        if (iSendMessage) {
+            IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
+        }
     }
 
     // Delete useless operation
