@@ -631,10 +631,29 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 if (iRole == Qt::UserRole) {
                     return -obj->getID();   // For sorting
                 } else {
-                    return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
-                                 getDocument()->getDisplay(m_groupby),
-                                 obj->getAttribute("t_title"),
-                                 rowCount(SKGObjectModelBase::index(iIndex.row(), 0)));
+                    int nb = rowCount(iIndex);
+
+                    // Is it possible to compute sums of f_CURRENTAMOUNT ?
+                    int posAmount = m_listAttibutes.indexOf("f_CURRENTAMOUNT");
+                    if (posAmount != -1) {
+                        // Compute sums
+                        double sum = 0.0;
+                        for (int i = 0; i < nb ; ++i) {
+                            sum += data(SKGObjectModelBase::index(i, posAmount, iIndex), Qt::UserRole).toDouble();
+                        }
+
+                        return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3) %4",
+                                     getDocument()->getDisplay(m_groupby),
+                                     obj->getAttribute("t_title"),
+                                     nb,
+                                     formatMoney(sum)
+                                    );
+                    } else {
+                        return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
+                                     getDocument()->getDisplay(m_groupby),
+                                     obj->getAttribute("t_title"),
+                                     nb);
+                    }
                 }
             }
             return "";
@@ -646,30 +665,30 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
             } else {
                 // This is a real attribute
                 val = obj->getAttribute(att);
-            }
 
-            switch (getAttributeType(iIndex.column())) {
-            case SKGServices::FLOAT: {
-                double dval = SKGServices::stringToDouble(val);
-                return dval;
-            }
-            case SKGServices::INTEGER: {
-                return SKGServices::stringToInt(val);
-            }
-            case SKGServices::DATE: {
-                QDate dval = SKGServices::stringToTime(val).date();
-                if (iRole == Qt::DisplayRole) {
-                    return KGlobal::locale()->formatDate(dval, static_cast<KLocale::DateFormat>(skgbasegui_settings::date_format()));
-                } else {
+                switch (getAttributeType(iIndex.column())) {
+                case SKGServices::FLOAT: {
+                    double dval = SKGServices::stringToDouble(val);
                     return dval;
                 }
-            }
-            default: {
-            }
-            }
+                case SKGServices::INTEGER: {
+                    return SKGServices::stringToInt(val);
+                }
+                case SKGServices::DATE: {
+                    QDate dval = SKGServices::stringToTime(val).date();
+                    if (iRole == Qt::DisplayRole) {
+                        return KGlobal::locale()->formatDate(dval, static_cast<KLocale::DateFormat>(skgbasegui_settings::date_format()));
+                    } else {
+                        return dval;
+                    }
+                }
+                default: {
+                }
+                }
 
-            if (m_doctransactionTable && att == "t_savestep") {
-                return "";
+                if (m_doctransactionTable && att == "t_savestep") {
+                    return "";
+                }
             }
 
             // return val+"("+SKGServices::intToString(rowCount(index))+")";
@@ -1040,4 +1059,9 @@ QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject
     }
 }
 
+QString SKGObjectModelBase::formatMoney(double iValue) const
+{
+    return SKGServices::doubleToString(iValue);
+}
+
 #include "skgobjectmodelbase.moc"
