@@ -324,14 +324,7 @@ void SKGTreeView::setState(const QString& iState)
             m_model->setGroupBy(att);
             m_model->dataModified();
 
-            bool treeMode = !m_model->getParentChildAttribute().isEmpty();
-            setRootIsDecorated(treeMode && m_groupby.isEmpty());
-            if (m_actExpandAll) {
-                m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-            }
-            if (m_actCollapseAll) {
-                m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
-            }
+            refreshExpandCollapse();
         }
 
         // Set alternatingRowColors
@@ -352,20 +345,25 @@ void SKGTreeView::setState(const QString& iState)
             m_model->setGroupBy(m_groupby);
             m_model->dataModified();
 
-            bool treeMode = !m_model->getParentChildAttribute().isEmpty();
-            setRootIsDecorated(treeMode && m_groupby.isEmpty());
-            if (m_actExpandAll) {
-                m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-            }
-            if (m_actCollapseAll) {
-                m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
-            }
+            refreshExpandCollapse();
         }
 
         this->sortByColumn(0, qtsortorder);
     }
 }
 
+void SKGTreeView::refreshExpandCollapse()
+{
+    bool treeMode = !m_model->getParentChildAttribute().isEmpty();
+    setRootIsDecorated(treeMode && m_groupby.isEmpty());
+    if (m_actExpandAll) {
+        m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+    }
+    if (m_actCollapseAll) {
+        m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+    }
+}
+
 void SKGTreeView::onRangeChanged()
 {
     QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
@@ -658,14 +656,7 @@ void SKGTreeView::groupByChanged(QAction* iAction)
         m_model->setGroupBy(att);
         m_model->refresh();
 
-        bool treeMode = !m_model->getParentChildAttribute().isEmpty();
-        setRootIsDecorated(treeMode && m_groupby.isEmpty());
-        if (m_actExpandAll) {
-            m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-        }
-        if (m_actCollapseAll) {
-            m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
-        }
+        refreshExpandCollapse();
     }
 }
 
@@ -1284,6 +1275,8 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
             connect(m_model, SIGNAL(afterReset()), this, SLOT(onSelectionChanged()));
         }
         QTreeView::setModel(iModel);
+
+        refreshExpandCollapse();
     }
 }
 
